# syned
SYNchrotron Elements Dictionary

[![spack](https://img.shields.io/spack/v/py-syned)](https://spack.readthedocs.io/en/latest/package_list.html#py-syned)


A python library to define the components of a synchrotron beamline and their positions. They can be read/write to json files. It is used by OASYS as a common tool to define sources and optical systems that are then exported to the different add-ons. 

## Reference

[1] https://doi.org/10.1117/12.2274232

